@@ -74,6 +74,7 @@
 #define IDS_ALL_SERVERS_RUNNING                65
 #define IDS_CHECK_VOLUMES_OK                   66
 #define IDS_CHECK_VOLUMES_ERROR                67
+#define IDS_INVALID_ACL_DATA                   68
 
 #define IDS_ACL_ENTRY_NAME_IN_USE              80
 #define IDS_REALLY_DEL_MOUNT_POINTS            81
@@ -118,7 +119,7 @@
 #define IDS_REALLY_REMOVE_SYMLINK              118
 
 #define IDS_SYMBOLICLINK_ADD                   128
-#define IDS_SYMBOLICLINK_EDIT                  129
+#define IDS_SYMBOLICLINK_SHOW                  129
 #define IDS_SYMBOLICLINK_REMOVE                130
 #define IDS_SYMBOLIC_LINK_ITEM                 131
 #define IDS_UNABLE_TO_CREATE_SYMBOLIC_LINK     132
@@ -127,7 +128,10 @@
 #define IDS_CLEANACL_ERROR                     135
 #define IDS_MAKE_LNK_NOT_AFS_ERROR             136
 #define IDS_NOT_AFS_CLIENT_ADMIN_ERROR         137
-                                           
+#define IDS_WARNING			       138
+#define IDS_VOLUME_NOT_IN_CELL_WARNING         139
+#define IDS_NOT_SYMLINK_ERROR                  140
+
 #define IDM_AUTHENTICATION                    0
 #define IDM_ACL_SET                           1
 #define IDM_VOLUME_PROPERTIES                 2
@@ -146,7 +150,8 @@
 #define IDM_ACL_CLEAN                         15
 #define IDM_SUBMOUNTS_EDIT                    16
 #define IDM_REMOVE_SYMLINK                    17
-                                           
+#define IDM_SYMBOLICLINK_SHOW		      18
+
 #define ID_GET_TOKENS                   917
 #define ID_DISCARD_TOKENS               918
 #define IDD_KLOG_DIALOG                 920
@@ -175,6 +180,8 @@
 #define ID_REMOVE_SYMLINK               957
 #define ID_SYMBOLICLINK_ADD             958
 #define ID_SYMBOLICLINK_REMOVE          959
+#define ID_SYMBOLICLINK_SHOW            960
+#define IDD_SYMLINKS                    961
 #define IDC_LIST                        1001
 #define IDC_PASSWORD                    1002
 #define IDC_OFFLINE_MSG                 1003
