@@ -25,18 +25,14 @@
 #include <sys/mutex.h>
 #endif
 
-extern struct simplelock afs_rxglobal_lock;
-
 /* 
  * Time related macros
  */
 #define osi_Time()	time_second
 #define	afs_hz		hz
 
-#define PAGESIZE 8192
-
-#define	AFS_UCRED	ucred
-#define	AFS_PROC	struct proc
+typedef struct ucred afs_ucred_t;
+typedef struct proc afs_proc_t;
 
 #define afs_bufferpages bufpages
 #ifndef iodone
@@ -44,16 +40,25 @@ extern struct simplelock afs_rxglobal_lock;
 #endif
 
 #define osi_vnhold(avc,r)	vref(AFSTOV(avc))
-#undef vSetVfsp
-#define vSetVfsp(vc, vfsp)	AFSTOV(vc)->v_mount = (vfsp)
-#undef vSetType
-#define vSetType(vc, type)	AFSTOV(vc)->v_type = (type)
-#undef vType
-#define	vType(vc)		AFSTOV(vc)->v_type
+
+#define vType(vc)               AFSTOV(vc)->v_type
+#define vSetVfsp(vc, vfsp) 	AFSTOV(vc)->v_mount = (vfsp)
+#define vSetType(vc, type)      AFSTOV(vc)->v_type = (type)
+#if defined(AFS_FBSD60_ENV) && defined(KERNEL)
+extern struct vop_vector afs_vnodeops;
+# define IsAfsVnode(v) ((v)->v_op == &afs_vnodeops)
+#else
+extern int (**afs_vnodeop_p) ();
+# define IsAfsVnode(v)           ((v)->v_op == afs_vnodeop_p)
+#endif
+#define SetAfsVnode(v)          /* nothing; done in getnewvnode() */
 
 #undef gop_lookupname
 #define gop_lookupname osi_lookupname
 
+#undef gop_lookupname_user
+#define gop_lookupname osi_lookupname_user
+
 #undef afs_suser
 
 #define afs_strcat(s1, s2)	strcat((s1), (s2))
@@ -63,22 +68,26 @@ extern struct simplelock afs_rxglobal_lock;
 #undef afs_osi_Alloc_NoSleep
 #define afs_osi_Alloc_NoSleep(size) osi_fbsd_alloc((size), 0)
 
-#define VN_RELE(vp)		vrele(vp)
+#ifdef AFS_FBSD80_ENV
+#define VN_RELE(vp)				\
+  do {						\
+    vrele(vp);					\
+  } while(0);
+#else
+#define VN_RELE(vp)             vrele(vp)
+#endif
 #define VN_HOLD(vp)		VREF(vp)
 
-#ifdef AFS_FBSD60_ENV
-#undef IsAfsVnode
-#define IsAfsVnode(v) ((v)->v_op == &afs_vnodeops)
-extern struct vop_vector afs_vnodeops;
-#endif
 
+
+#undef osi_getpid
 #if defined(AFS_FBSD50_ENV)
 #define VT_AFS		"afs"
 #define VROOT		VV_ROOT
 #define v_flag		v_vflag
 #define osi_curcred()	(curthread->td_ucred)
 #define afs_suser(x)	(!suser(curthread))
-#define getpid()	(curthread->td_proc->p_pid)
+#define osi_getpid()	(curthread->td_proc->p_pid)
 #define simple_lock(x)	mtx_lock(x)
 #define simple_unlock(x) mtx_unlock(x)
 #define        gop_rdwr(rw,gp,base,len,offset,segflg,unit,cred,aresid) \
@@ -87,13 +96,11 @@ extern struct mtx afs_global_mtx;
 #define AFS_GLOCK() mtx_lock(&afs_global_mtx)
 #define AFS_GUNLOCK() mtx_unlock(&afs_global_mtx)
 #define ISAFS_GLOCK() (mtx_owned(&afs_global_mtx))
-
 #else /* FBSD50 */
 extern struct lock afs_global_lock;
-
 #define osi_curcred()	(curproc->p_cred->pc_ucred)
 #define afs_suser(x)	(!suser(curproc))
-#define getpid()	(curproc->p_pid)
+#define osi_getpid()	(curproc->p_pid)
 #define        gop_rdwr(rw,gp,base,len,offset,segflg,unit,cred,aresid) \
   vn_rdwr((rw),(gp),(base),(len),(offset),(segflg),(unit),(cred),(aresid), curproc)
 extern struct proc *afs_global_owner;
@@ -122,4 +129,6 @@ extern struct proc *afs_global_owner;
 #define USERPRI splx(splvar)
 #endif /* KERNEL */
 
+#define ifnet_flags(x) (x?(x)->if_flags:0)
+
 #endif /* _OSI_MACHDEP_H_ */
