@@ -27,7 +27,8 @@ extern time_t time;
 #define osi_Time() (time)
 
 /* This gets redefined from ucred to cred in osi_vfs.h, just do it right */
-#define	AFS_UCRED	struct cred
+typedef struct cred afs_ucred_t;
+typedef struct proc afs_proc_t;
 
 #undef gop_lookupname
 #define gop_lookupname(fnamep,segflg,followlink,compvpp) lookupname((fnamep),(segflg),(followlink),NULL,(compvpp), NULL)
