@@ -8,13 +8,11 @@
  */
 
 /*
- * osi_vfsops.c for DUX
+ * osi_vfsops.c for NetBSD
  */
 #include <afsconfig.h>
 #include "afs/param.h"
 
-RCSID
-    ("$Header: /cvs/openafs/src/afs/NBSD/osi_vfsops.c,v 1.8.14.1 2009/01/26 18:52:41 shadow Exp $");
 
 #include "afs/sysincludes.h"	/* Standard vendor system headers */
 #include "afsincludes.h"	/* Afs-based standard headers */
