@@ -23,8 +23,6 @@
 #include <afsconfig.h>
 #include "afs/param.h"
 
-RCSID
-    ("$Header: /cvs/openafs/src/afs/VNOPS/afs_vnop_attrs.c,v 1.41.2.3 2008/09/22 19:29:55 shadow Exp $");
 
 #include "afs/sysincludes.h"	/* Standard vendor system headers */
 #include "afsincludes.h"	/* Afs-based standard headers */
@@ -54,14 +52,14 @@ afs_CopyOutAttrs(register struct vcache *avc, register struct vattr *attrs)
 	fakedir = 1;
     attrs->va_type = fakedir ? VDIR : vType(avc);
 #if defined(AFS_SGI_ENV) || defined(AFS_AIX32_ENV) || defined(AFS_SUN5_ENV)
-    attrs->va_mode = fakedir ? 0755 : (mode_t) (avc->m.Mode & 0xffff);
+    attrs->va_mode = fakedir ? 0755 : (mode_t) (avc->f.m.Mode & 0xffff);
 #else
-    attrs->va_mode = fakedir ? VDIR | 0755 : avc->m.Mode;
+    attrs->va_mode = fakedir ? VDIR | 0755 : avc->f.m.Mode;
 #endif
 
-    if (avc->m.Mode & (VSUID | VSGID)) {
+    if (avc->f.m.Mode & (VSUID | VSGID)) {
 	/* setuid or setgid, make sure we're allowed to run them from this cell */
-	tcell = afs_GetCell(avc->fid.Cell, 0);
+	tcell = afs_GetCell(avc->f.fid.Cell, 0);
 	if (tcell && (tcell->states & CNoSUID))
 	    attrs->va_mode &= ~(VSUID | VSGID);
     }
@@ -88,12 +86,10 @@ afs_CopyOutAttrs(register struct vcache *avc, register struct vattr *attrs)
 	}
     }
 #endif /* AFS_DARWIN_ENV */
-    attrs->va_uid = fakedir ? 0 : avc->m.Owner;
-    attrs->va_gid = fakedir ? 0 : avc->m.Group;	/* yeah! */
+    attrs->va_uid = fakedir ? 0 : avc->f.m.Owner;
+    attrs->va_gid = fakedir ? 0 : avc->f.m.Group;	/* yeah! */
 #if defined(AFS_SUN56_ENV)
     attrs->va_fsid = avc->v.v_vfsp->vfs_fsid.val[0];
-#elif defined(AFS_OSF_ENV)
-    attrs->va_fsid = avc->v.v_mount->m_stat.f_fsid.val[0];
 #elif defined(AFS_DARWIN80_ENV)
     VATTR_RETURN(attrs, va_fsid, vfs_statfs(vnode_mount(AFSTOV(avc)))->f_fsid.val[0]);
 #elif defined(AFS_DARWIN70_ENV)
@@ -102,26 +98,26 @@ afs_CopyOutAttrs(register struct vcache *avc, register struct vattr *attrs)
     attrs->va_fsid = 1;
 #endif 
     if (avc->mvstat == 2) {
-	tvp = afs_GetVolume(&avc->fid, 0, READ_LOCK);
+	tvp = afs_GetVolume(&avc->f.fid, 0, READ_LOCK);
 	/* The mount point's vnode. */
 	if (tvp) {
 	    attrs->va_nodeid =
 	      afs_calc_inum (tvp->mtpoint.Fid.Volume,
 			      tvp->mtpoint.Fid.Vnode);
-	    if (FidCmp(&afs_rootFid, &avc->fid) && !attrs->va_nodeid)
+	    if (FidCmp(&afs_rootFid, &avc->f.fid) && !attrs->va_nodeid)
 		attrs->va_nodeid = 2;
 	    afs_PutVolume(tvp, READ_LOCK);
 	} else
 	    attrs->va_nodeid = 2;
     } else
 	attrs->va_nodeid = 
-	      afs_calc_inum (avc->fid.Fid.Volume,
-			      avc->fid.Fid.Vnode);
+	      afs_calc_inum (avc->f.fid.Fid.Volume,
+			      avc->f.fid.Fid.Vnode);
     attrs->va_nodeid &= 0x7fffffff;	/* Saber C hates negative inode #s! */
-    attrs->va_nlink = fakedir ? 100 : avc->m.LinkCount;
-    attrs->va_size = fakedir ? 4096 : avc->m.Length;
+    attrs->va_nlink = fakedir ? 100 : avc->f.m.LinkCount;
+    attrs->va_size = fakedir ? 4096 : avc->f.m.Length;
     attrs->va_atime.tv_sec = attrs->va_mtime.tv_sec = attrs->va_ctime.tv_sec =
-	fakedir ? 0 : (int)avc->m.Date;
+	fakedir ? 0 : (int)avc->f.m.Date;
     /* set microseconds to be dataversion # so that we approximate NFS-style
      * use of mtime as a dataversion #.  We take it mod 512K because
      * microseconds *must* be less than a million, and 512K is the biggest
@@ -135,16 +131,16 @@ afs_CopyOutAttrs(register struct vcache *avc, register struct vattr *attrs)
 
     attrs->va_atime.tv_nsec = attrs->va_mtime.tv_nsec =
 	attrs->va_ctime.tv_nsec = 0;
-    attrs->va_gen = hgetlo(avc->m.DataVersion);
+    attrs->va_gen = hgetlo(avc->f.m.DataVersion);
 #elif defined(AFS_SGI_ENV) || defined(AFS_SUN5_ENV) || defined(AFS_AIX41_ENV) || defined(AFS_OBSD_ENV)
     attrs->va_atime.tv_nsec = attrs->va_mtime.tv_nsec =
 	attrs->va_ctime.tv_nsec =
-	(hgetlo(avc->m.DataVersion) & 0x7ffff) * 1000;
+	(hgetlo(avc->f.m.DataVersion) & 0x7ffff) * 1000;
 #else
     attrs->va_atime.tv_usec = attrs->va_mtime.tv_usec =
-	attrs->va_ctime.tv_usec = (hgetlo(avc->m.DataVersion) & 0x7ffff);
+	attrs->va_ctime.tv_usec = (hgetlo(avc->f.m.DataVersion) & 0x7ffff);
 #endif
-#if defined(AFS_DARWIN_ENV) || defined(AFS_XBSD_ENV) || defined(AFS_OSF_ENV)
+#if defined(AFS_DARWIN_ENV) || defined(AFS_XBSD_ENV)
     attrs->va_flags = 0;
 #endif
 #if defined(AFS_SGI_ENV) || defined(AFS_SUN5_ENV)
@@ -162,7 +158,7 @@ afs_CopyOutAttrs(register struct vcache *avc, register struct vattr *attrs)
      * Below return 0 (and not 1) blocks if the file is zero length. This conforms
      * better with the other filesystems that do return 0.      
      */
-#if defined(AFS_OSF_ENV) || defined(AFS_DARWIN_ENV) || defined(AFS_XBSD_ENV)
+#if defined(AFS_DARWIN_ENV) || defined(AFS_XBSD_ENV)
     attrs->va_bytes = (attrs->va_size ? (attrs->va_size + 1023) : 1024);
 #ifdef	va_bytes_rsv
     attrs->va_bytes_rsv = -1;
@@ -184,22 +180,21 @@ afs_CopyOutAttrs(register struct vcache *avc, register struct vattr *attrs)
 #if	defined(AFS_SUN5_ENV) || defined(AFS_SGI_ENV)
 int
 afs_getattr(OSI_VC_DECL(avc), struct vattr *attrs, int flags,
-	    struct AFS_UCRED *acred)
+	    afs_ucred_t *acred)
 #else
 int
-afs_getattr(OSI_VC_DECL(avc), struct vattr *attrs, struct AFS_UCRED *acred)
+afs_getattr(OSI_VC_DECL(avc), struct vattr *attrs, afs_ucred_t *acred)
 #endif
 {
     afs_int32 code;
     struct vrequest treq;
-    extern struct unixuser *afs_FindUser();
     struct unixuser *au;
     int inited = 0;
     OSI_VC_CONVERT(avc);
 
     AFS_STATCNT(afs_getattr);
     afs_Trace2(afs_iclSetp, CM_TRACE_GETATTR, ICL_TYPE_POINTER, avc,
-	       ICL_TYPE_OFFSET, ICL_HANDLE_OFFSET(avc->m.Length));
+	       ICL_TYPE_OFFSET, ICL_HANDLE_OFFSET(avc->f.m.Length));
 
     if (afs_fakestat_enable && avc->mvstat == 1) {
 	struct afs_fakestat_state fakestat;
@@ -225,7 +220,7 @@ afs_getattr(OSI_VC_DECL(avc), struct vattr *attrs, struct AFS_UCRED *acred)
     }
 #endif
 #if defined(AFS_DARWIN_ENV) && !defined(AFS_DARWIN80_ENV)
-    if (avc->states & CUBCinit) {
+    if (avc->f.states & CUBCinit) {
 	code = afs_CopyOutAttrs(avc, attrs);
 	return code;
     }
@@ -240,7 +235,7 @@ afs_getattr(OSI_VC_DECL(avc), struct vattr *attrs, struct AFS_UCRED *acred)
     if (afs_shuttingdown)
 	return EIO;
 
-    if (!(avc->states & CStatd)) {
+    if (!(avc->f.states & CStatd)) {
 	if (!(code = afs_InitReq(&treq, acred))) {
 	    code = afs_VerifyVCache2(avc, &treq);
 	    inited = 1;
@@ -353,7 +348,7 @@ afs_VAttrToAS(register struct vcache *avc, register struct vattr *av,
 #elif	defined(AFS_AIX_ENV)
 /* Boy, was this machine dependent bogosity hard to swallow????.... */
     if (av->va_mode != -1) {
-#elif	defined(AFS_LINUX22_ENV)
+#elif	defined(AFS_LINUX22_ENV) || defined(UKERNEL)
     if (av->va_mask & ATTR_MODE) {
 #elif	defined(AFS_SUN5_ENV) || defined(AFS_SGI_ENV)
     if (av->va_mask & AT_MODE) {
@@ -364,7 +359,7 @@ afs_VAttrToAS(register struct vcache *avc, register struct vattr *av,
 #endif
 	mask |= AFS_SETMODE;
 	as->UnixModeBits = av->va_mode & 0xffff;
-	if (avc->states & CForeign) {
+	if (avc->f.states & CForeign) {
 	    ObtainWriteLock(&avc->lock, 127);
 	    afs_FreeAllAxs(&(avc->Access));
 	    ReleaseWriteLock(&avc->lock);
@@ -372,7 +367,7 @@ afs_VAttrToAS(register struct vcache *avc, register struct vattr *av,
     }
 #if     defined(AFS_DARWIN80_ENV)
     if (VATTR_IS_ACTIVE(av, va_gid)) {
-#elif defined(AFS_LINUX22_ENV)
+#elif defined(AFS_LINUX22_ENV) || defined(UKERNEL)
     if (av->va_mask & ATTR_GID) {
 #elif defined(AFS_SUN5_ENV) || defined(AFS_SGI_ENV)
     if (av->va_mask & AT_GID) {
@@ -392,7 +387,7 @@ afs_VAttrToAS(register struct vcache *avc, register struct vattr *av,
     }
 #if     defined(AFS_DARWIN80_ENV)
     if (VATTR_IS_ACTIVE(av, va_uid)) {
-#elif defined(AFS_LINUX22_ENV)
+#elif defined(AFS_LINUX22_ENV) || defined(UKERNEL)
     if (av->va_mask & ATTR_UID) {
 #elif defined(AFS_SUN5_ENV) || defined(AFS_SGI_ENV)
     if (av->va_mask & AT_UID) {
@@ -412,7 +407,7 @@ afs_VAttrToAS(register struct vcache *avc, register struct vattr *av,
     }
 #if     defined(AFS_DARWIN80_ENV)
     if (VATTR_IS_ACTIVE(av, va_modify_time)) {
-#elif	defined(AFS_LINUX22_ENV)
+#elif	defined(AFS_LINUX22_ENV) || defined(UKERNEL)
     if (av->va_mask & ATTR_MTIME) {
 #elif	defined(AFS_SUN5_ENV) || defined(AFS_SGI_ENV)
     if (av->va_mask & AT_MTIME) {
@@ -435,17 +430,17 @@ afs_VAttrToAS(register struct vcache *avc, register struct vattr *av,
     return 0;
 }
 
-/* We don't set CDirty bit in avc->states because setattr calls WriteVCache
+/* We don't set CDirty bit in avc->f.states because setattr calls WriteVCache
  * synchronously, therefore, it's not needed.
  */
 #if defined(AFS_SUN5_ENV) || defined(AFS_SGI_ENV)
 int
 afs_setattr(OSI_VC_DECL(avc), register struct vattr *attrs, int flags,
-	    struct AFS_UCRED *acred)
+	    afs_ucred_t *acred)
 #else
 int
 afs_setattr(OSI_VC_DECL(avc), register struct vattr *attrs,
-	    struct AFS_UCRED *acred)
+	    afs_ucred_t *acred)
 #endif
 {
     struct vrequest treq;
@@ -459,12 +454,12 @@ afs_setattr(OSI_VC_DECL(avc), register struct vattr *attrs,
     afs_Trace4(afs_iclSetp, CM_TRACE_SETATTR, ICL_TYPE_POINTER, avc,
 	       ICL_TYPE_INT32, attrs->va_mask, ICL_TYPE_OFFSET,
 	       ICL_HANDLE_OFFSET(attrs->va_size), ICL_TYPE_OFFSET,
-	       ICL_HANDLE_OFFSET(avc->m.Length));
+	       ICL_HANDLE_OFFSET(avc->f.m.Length));
 #else
     afs_Trace4(afs_iclSetp, CM_TRACE_SETATTR, ICL_TYPE_POINTER, avc,
 	       ICL_TYPE_INT32, attrs->va_mode, ICL_TYPE_OFFSET,
 	       ICL_HANDLE_OFFSET(attrs->va_size), ICL_TYPE_OFFSET,
-	       ICL_HANDLE_OFFSET(avc->m.Length));
+	       ICL_HANDLE_OFFSET(avc->f.m.Length));
 #endif
     if ((code = afs_InitReq(&treq, acred)))
 	return code;
@@ -476,7 +471,7 @@ afs_setattr(OSI_VC_DECL(avc), register struct vattr *attrs,
     if (code)
 	goto done;
 
-    if (avc->states & CRO) {
+    if (avc->f.states & CRO) {
 	code = EROFS;
 	goto done;
     }
@@ -493,11 +488,11 @@ afs_setattr(OSI_VC_DECL(avc), register struct vattr *attrs,
      */
 #if	defined(AFS_DARWIN80_ENV)
     if (VATTR_IS_ACTIVE(attrs, va_data_size)) {
-#elif	defined(AFS_LINUX22_ENV)
+#elif	defined(AFS_LINUX22_ENV) || defined(UKERNEL)
     if (attrs->va_mask & ATTR_SIZE) {
 #elif	defined(AFS_SUN5_ENV) || defined(AFS_SGI_ENV)
     if (attrs->va_mask & AT_SIZE) {
-#elif	defined(AFS_OSF_ENV) || defined(AFS_XBSD_ENV)
+#elif	defined(AFS_XBSD_ENV)
     if (attrs->va_size != VNOVAL) {
 #elif	defined(AFS_AIX41_ENV)
     if (attrs->va_size != -1) {
@@ -531,20 +526,35 @@ afs_setattr(OSI_VC_DECL(avc), register struct vattr *attrs,
 #endif
 #if	defined(AFS_DARWIN80_ENV)
     if (VATTR_IS_ACTIVE(attrs, va_data_size)) {
-#elif	defined(AFS_LINUX22_ENV)
+#elif	defined(AFS_LINUX22_ENV) || defined(UKERNEL)
     if (attrs->va_mask & ATTR_SIZE) {
 #elif	defined(AFS_SUN5_ENV) || defined(AFS_SGI_ENV)
     if (attrs->va_mask & AT_SIZE) {
-#elif	defined(AFS_OSF_ENV) || defined(AFS_XBSD_ENV)
+#elif	defined(AFS_XBSD_ENV)
     if (attrs->va_size != VNOVAL) {
-#else
+#elif	defined(AFS_AIX41_ENV)
     if (attrs->va_size != -1) {
+#else
+    if (attrs->va_size != ~0) {
 #endif
 	afs_size_t tsize = attrs->va_size;
 	ObtainWriteLock(&avc->lock, 128);
-	avc->states |= CDirty;
+	avc->f.states |= CDirty;
 
-	code = afs_TruncateAllSegments(avc, tsize, &treq, acred);
+        if (AFS_IS_DISCONNECTED && tsize >=avc->f.m.Length) {
+	    /* If we're growing the file, and we're disconnected, we need
+ 	     * to make the relevant dcache chunks appear ourselves. */
+	    code = afs_ExtendSegments(avc, tsize, &treq);
+	} else {
+	    code = afs_TruncateAllSegments(avc, tsize, &treq, acred);
+	}
+#ifdef AFS_LINUX26_ENV
+	/* We must update the Linux kernel's idea of file size as soon as
+	 * possible, to avoid racing with delayed writepages delivered by
+	 * pdflush */
+	if (code == 0)
+	    i_size_write(AFSTOV(avc), tsize);
+#endif
 	/* if date not explicitly set by this call, set it ourselves, since we
 	 * changed the data */
 	if (!(astat.Mask & AFS_SETMODTIME)) {
@@ -553,7 +563,7 @@ afs_setattr(OSI_VC_DECL(avc), register struct vattr *attrs,
 	}
 
 	if (code == 0) {
-	    if (((avc->execsOrWriters <= 0) && (avc->states & CCreating) == 0)
+	    if (((avc->execsOrWriters <= 0) && (avc->f.states & CCreating) == 0)
 		|| (avc->execsOrWriters == 1 && AFS_NFSXLATORREQ(acred))) {
 
 		/* Store files now if not disconnected. */
@@ -561,11 +571,11 @@ afs_setattr(OSI_VC_DECL(avc), register struct vattr *attrs,
 		if (!AFS_IS_DISCONNECTED) {
 			code = afs_StoreAllSegments(avc, &treq, AFS_ASYNC);
 			if (!code)
-		    		avc->states &= ~CDirty;
+		    		avc->f.states &= ~CDirty;
 		}
 	    }
 	} else
-	    avc->states &= ~CDirty;
+	    avc->f.states &= ~CDirty;
 
 	ReleaseWriteLock(&avc->lock);
 	hzero(avc->flushDV);
@@ -581,9 +591,9 @@ afs_setattr(OSI_VC_DECL(avc), register struct vattr *attrs,
         if (code) {
 	    ObtainWriteLock(&afs_xcbhash, 487);
 	    afs_DequeueCallback(avc);
-	    avc->states &= ~CStatd;
+	    avc->f.states &= ~CStatd;
 	    ReleaseWriteLock(&afs_xcbhash);
-	    if (avc->fid.Fid.Vnode & 1 || (vType(avc) == VDIR))
+	    if (avc->f.fid.Fid.Vnode & 1 || (vType(avc) == VDIR))
 	        osi_dnlc_purgedp(avc);
 	    /* error?  erase any changes we made to vcache entry */
         }
