@@ -15,8 +15,6 @@
 #include <afsconfig.h>
 #include "afs/param.h"
 
-RCSID
-    ("$Header: /cvs/openafs/src/afs/VNOPS/afs_vnop_flock.c,v 1.29.2.10 2009/05/27 00:47:53 shadow Exp $");
 
 #include "afs/sysincludes.h"	/* Standard vendor system headers */
 #include "afsincludes.h"	/* Afs-based standard headers */
@@ -41,105 +39,121 @@ static int lockIdcmp2(struct AFS_FLOCK *flock1, struct vcache *vp,
 static void DoLockWarning(void);
 
 /* int clid;  * non-zero on SGI, OSF, SunOS, Darwin, xBSD ** XXX ptr type */
+
+#if defined(AFS_SUN5_ENV)
 void
 lockIdSet(struct AFS_FLOCK *flock, struct SimpleLocks *slp, int clid)
 {
-#if	defined(AFS_SUN5_ENV)
-    register proc_t *procp = ttoproc(curthread);
-#else
-#if !defined(AFS_AIX41_ENV) && !defined(AFS_LINUX20_ENV) && !defined(AFS_SGI65_ENV) && !defined(AFS_DARWIN_ENV) && !defined(AFS_XBSD_ENV)
-#ifdef AFS_SGI_ENV
-    struct proc *procp = OSI_GET_CURRENT_PROCP();
-#else
-    struct proc *procp = u.u_procp;
-#endif /* AFS_SGI_ENV */
-#endif
-#endif
-#if defined(AFS_SGI65_ENV)
-    flid_t flid;
-    get_current_flid(&flid);
-#endif
+    proc_t *procp = ttoproc(curthread);
 
     if (slp) {
-#ifdef	AFS_AIX32_ENV
-#ifdef	AFS_AIX41_ENV
-	slp->sysid = 0;
-	slp->pid = getpid();
-#else
-	slp->sysid = u.u_sysid;
-	slp->pid = u.u_epid;
-#endif
-#else
-#if	defined(AFS_AIX_ENV) || defined(AFS_SUN5_ENV)
-#ifdef	AFS_SUN53_ENV
+# ifdef AFS_SUN53_ENV
 	slp->sysid = 0;
 	slp->pid = procp->p_pid;
-#else
+# else
 	slp->sysid = procp->p_sysid;
 	slp->pid = procp->p_epid;
-#endif
-#else
-#if defined(AFS_SGI_ENV)
-#ifdef AFS_SGI65_ENV
-	slp->sysid = flid.fl_sysid;
-#else
-	slp->sysid = OSI_GET_CURRENT_SYSID();
-#endif
-	slp->pid = clid;
-#else
-#if	defined(AFS_OSF_ENV) || defined(AFS_DARWIN_ENV) || defined(AFS_XBSD_ENV)
-	slp->pid = clid;
-#else
-#if defined(AFS_LINUX20_ENV) || defined(AFS_HPUX_ENV)
-	slp->pid = getpid();
-#else
-	slp->pid = u.u_procp->p_pid;
-#endif
-#endif
-#endif /* AFS_AIX_ENV */
-#endif /* AFS_AIX32_ENV */
-#endif
+# endif
     } else {
-#if	defined(AFS_AIX32_ENV)
-#ifdef	AFS_AIX41_ENV
-	flock->l_sysid = 0;
-	flock->l_pid = getpid();
-#else
-	flock->l_sysid = u.u_sysid;
-	flock->l_pid = u.u_epid;
-#endif
-#else
-#if	defined(AFS_AIX_ENV)  || defined(AFS_SUN5_ENV)
-#ifdef	AFS_SUN53_ENV
+# ifdef AFS_SUN53_ENV
 	flock->l_sysid = 0;
 	flock->l_pid = procp->p_pid;
-#else
+# else
 	flock->l_sysid = procp->p_sysid;
 	flock->l_pid = procp->p_epid;
-#endif
-#else
-#if defined(AFS_SGI_ENV)
-#ifdef AFS_SGI65_ENV
-	flock->l_sysid = flid.fl_sysid;
-#else
-	flock->l_sysid = OSI_GET_CURRENT_SYSID();
-#endif
-	flock->l_pid = clid;
-#else
-#if	defined(AFS_OSF_ENV) || defined(AFS_DARWIN_ENV) || defined(AFS_XBSD_ENV)
-	flock->l_pid = clid;
-#else
-#if defined(AFS_LINUX20_ENV) || defined(AFS_HPUX_ENV)
-	flock->l_pid = getpid();
-#else
-	flock->l_pid = u.u_procp->p_pid;
-#endif
-#endif
-#endif
-#endif /* AFS_AIX_ENV */
-#endif /* AFS_AIX32_ENV */
+# endif
     }
 }
+#elif defined(AFS_SGI_ENV)
+void
+lockIdSet(struct AFS_FLOCK *flock, struct SimpleLocks *slp, int clid)
+{
+# if defined(AFS_SGI65_ENV)
+    flid_t flid;
+    get_current_flid(&flid);
+# else
+    afs_proc_t *procp = OSI_GET_CURRENT_PROCP();
+# endif
+
+    if (slp) {
+# ifdef AFS_SGI65_ENV
+	slp->sysid = flid.fl_sysid;
+# else
+	slp->sysid = OSI_GET_CURRENT_SYSID();
+# endif
+	slp->pid = clid;
+    } else {
+# ifdef AFS_SGI65_ENV
+	flock->l_sysid = flid.fl_sysid;
+# else
+	flock->l_sysid = OSI_GET_CURRENT_SYSID();
+# endif
+	flock->l_pid = clid;
+    }
+}
+#elif defined(AFS_AIX_ENV)
+void
+lockIdSet(struct AFS_FLOCK *flock, struct SimpleLocks *slp, int clid)
+{
+# if !defined(AFS_AIX32_ENV)
+    afs_proc_t *procp = u.u_procp;
+# endif
+
+    if (slp) {
+# if defined(AFS_AIX41_ENV)
+	slp->sysid = 0;
+	slp->pid = getpid();
+# elif defined(AFS_AIX32_ENV)
+	slp->sysid = u.u_sysid;
+	slp->pid = u.u_epid;
+# else
+	slp->sysid = procp->p_sysid;
+	slp->pid = prcop->p_epid;
+# endif
+    } else {
+# if defined(AFS_AIX41_ENV)
+	flock->l_sysid = 0;
+	flock->l_pid = getpid();
+# elif defined(AFS_AIX32_ENV)
+	flock->l_sysid = u.u_sysid;
+	flock->l_pid = u.u_epid;
+# else
+	flock->l_sysid = procp->p_sysid;
+	flock->l_pid = procp->p_epid;
+# endif
+    }
+}
+#elif defined(AFS_DARWIN_ENV) || defined(AFS_XBSD_ENV)
+void
+lockIdSet(struct AFS_FLOCK *flock, struct SimpleLocks *slp, int clid)
+{
+    if (slp) {
+	slp->pid = clid;
+    } else {
+	flock->l_pid = clid;
+    }
+}
+#elif defined(AFS_LINUX20_ENV) || defined(AFS_HPUX_ENV)
+void
+lockIdSet(struct AFS_FLOCK *flock, struct SimpleLocks *slp, int clid)
+{
+    if (slp) {
+	slp->pid = getpid();
+    } else {
+	flock->l_pid = getpid();
+    }
+}
+#else
+void
+lockIdSet(struct AFS_FLOCK *flock, struct SimpleLocks *slp, int clid)
+{
+    if (slp) {
+	slp->pid = u.u_procp->p_pid;
+    } else {
+	flock->l_pid = u.u_procp->p_pid;
+    }
+}
+#endif
 
 /* return 1 (true) if specified flock does not match alp (if 
  * specified), or any of the slp structs (if alp == 0) 
@@ -162,9 +176,9 @@ lockIdcmp2(struct AFS_FLOCK *flock1, struct vcache *vp,
 #else
 #if !defined(AFS_AIX41_ENV) && !defined(AFS_LINUX20_ENV) && !defined(AFS_SGI65_ENV) && !defined(AFS_DARWIN_ENV) && !defined(AFS_XBSD_ENV)
 #ifdef AFS_SGI64_ENV
-    struct proc *procp = curprocp;
+    afs_proc_t *procp = curprocp;
 #else /* AFS_SGI64_ENV */
-    struct proc *procp = u.u_procp;
+    afs_proc_t *procp = u.u_procp;
 #endif /* AFS_SGI64_ENV */
 #endif
 #endif
@@ -495,23 +509,17 @@ DoLockWarning(void)
 }
 
 
-#ifdef	AFS_OSF_ENV
-int afs_lockctl(struct vcache * avc, struct eflock * af, int flag,
-		struct AFS_UCRED * acred, pid_t clid, off_t offset)
-#elif defined(AFS_SGI_ENV) || defined(AFS_DARWIN_ENV) || defined(AFS_XBSD_ENV)
+#if defined(AFS_SGI_ENV) || defined(AFS_DARWIN_ENV) || defined(AFS_XBSD_ENV)
 int afs_lockctl(struct vcache * avc, struct AFS_FLOCK * af, int acmd,
-		struct AFS_UCRED * acred, pid_t clid)
+		afs_ucred_t * acred, pid_t clid)
 #else
 u_int clid = 0;
 int afs_lockctl(struct vcache * avc, struct AFS_FLOCK * af, int acmd,
-		struct AFS_UCRED * acred)
+		afs_ucred_t * acred)
 #endif
 {
     struct vrequest treq;
     afs_int32 code;
-#ifdef	AFS_OSF_ENV
-    int acmd = 0;
-#endif
     struct afs_fakestat_state fakestate;
 
     AFS_STATCNT(afs_lockctl);
@@ -525,19 +533,6 @@ int afs_lockctl(struct vcache * avc, struct AFS_FLOCK * af, int acmd,
     if (code) {
 	goto done;
     }
-#ifdef	AFS_OSF_ENV
-    if (flag & VNOFLCK) {
-	code = 0;
-	goto done;
-    }
-    if (flag & CLNFLCK) {
-	acmd = LOCK_UN;
-    } else if ((flag & GETFLCK) || (flag & RGETFLCK)) {
-	acmd = F_GETLK;
-    } else if ((flag & SETFLCK) || (flag & RSETFLCK)) {
-	acmd = F_SETLK;
-    }
-#endif
 #if (defined(AFS_SGI_ENV) || defined(AFS_SUN5_ENV)) && !defined(AFS_SUN58_ENV)
     if ((acmd == F_GETLK) || (acmd == F_RGETLK)) {
 #else
@@ -547,9 +542,7 @@ int afs_lockctl(struct vcache * avc, struct AFS_FLOCK * af, int acmd,
 	    code = 0;
 	    goto done;
 	}
-#ifndef	AFS_OSF_ENV		/* getlock is a no-op for osf (for now) */
 	code = HandleGetLock(avc, af, &treq, clid);
-#endif
 	code = afs_CheckCode(code, &treq, 2);	/* defeat buggy AIX optimz */
 	goto done;
     } else if ((acmd == F_SETLK) || (acmd == F_SETLKW)
@@ -601,7 +594,7 @@ int afs_lockctl(struct vcache * avc, struct AFS_FLOCK * af, int acmd,
 #endif
 	) && code != LOCK_UN)
 	code |= LOCK_NB;	/* non-blocking, s.v.p. */
-#if	defined(AFS_OSF_ENV) || defined(AFS_DARWIN_ENV)
+#if defined(AFS_DARWIN_ENV)
     code = HandleFlock(avc, code, &treq, clid, 0 /*!onlymine */ );
 #elif defined(AFS_SGI_ENV)
     AFS_RWLOCK((vnode_t *) avc, VRWLOCK_WRITE);
@@ -632,7 +625,6 @@ done:
  *    2. Asking for write lock, and only the current
  *       PID has the file read locked.
  */
-#ifndef	AFS_OSF_ENV		/* getlock is a no-op for osf (for now) */
 static int
 HandleGetLock(register struct vcache *avc, register struct AFS_FLOCK *af,
 	      register struct vrequest *areq, int clid)
@@ -872,129 +864,4 @@ GetFlockCount(struct vcache *avc, struct vrequest *areq)
 	return ((int)OutStatus.lockCount);
     }
 }
-#endif
 
-
-#if	!defined(AFS_AIX_ENV) && !defined(AFS_HPUX_ENV) && !defined(AFS_SUN5_ENV) && !defined(AFS_SGI_ENV) && !defined(UKERNEL) && !defined(AFS_LINUX20_ENV) && !defined(AFS_DARWIN_ENV) && !defined(AFS_XBSD_ENV)
-/* Flock not support on System V systems */
-#ifdef AFS_OSF_ENV
-extern struct fileops afs_fileops;
-
-int
-afs_xflock(struct proc *p, void *args, int *retval)
-#else /* AFS_OSF_ENV */
-int
-afs_xflock(void)
-#endif
-{
-    int code = 0;
-    struct a {
-	int fd;
-	int com;
-    } *uap;
-    struct file *fd;
-    struct vrequest treq;
-    struct vcache *tvc;
-    int flockDone;
-    struct afs_fakestat_state fakestate;
-
-    afs_InitFakeStat(&fakestate);
-    AFS_STATCNT(afs_xflock);
-    flockDone = 0;
-#ifdef AFS_OSF_ENV
-    uap = (struct a *)args;
-    getf(&fd, uap->fd, FILE_FLAGS_NULL, &u.u_file_state);
-#else /* AFS_OSF_ENV */
-    uap = (struct a *)u.u_ap;
-    fd = getf(uap->fd);
-#endif
-    if (!fd) {
-	afs_PutFakeStat(&fakestate);
-	return;
-    }
-
-    if (flockDone = afs_InitReq(&treq, u.u_cred)) {
-	afs_PutFakeStat(&fakestate);
-	return flockDone;
-    }
-
-    AFS_DISCON_LOCK();
-    
-    /* first determine whether this is any sort of vnode */
-    if (fd->f_type == DTYPE_VNODE) {
-	/* good, this is a vnode; next see if it is an AFS vnode */
-	tvc = VTOAFS(fd->f_data);	/* valid, given a vnode */
-	if (IsAfsVnode(AFSTOV(tvc))) {
-	    /* This is an AFS vnode, so do the work */
-	    code = afs_EvalFakeStat(&tvc, &fakestate, &treq);
-	    if (code) {
-		AFS_DISCON_UNLOCK();
-		afs_PutFakeStat(&fakestate);
-		return code;
-	    }
-	    if ((fd->f_flag & (FEXLOCK | FSHLOCK)) && !(uap->com & LOCK_UN)) {
-		/* First, if fd already has lock, release it for relock path */
-#if defined(AFS_SGI_ENV) || defined(AFS_OSF_ENV)
-		HandleFlock(tvc, LOCK_UN, &treq, u.u_procp->p_pid,
-			    0 /*!onlymine */ );
-#else
-		HandleFlock(tvc, LOCK_UN, &treq, 0, 0 /*!onlymine */ );
-#endif
-		fd->f_flag &= ~(FEXLOCK | FSHLOCK);
-	    }
-	    /* now try the requested operation */
-
-#if defined(AFS_SGI_ENV) || defined(AFS_OSF_ENV)
-	    code =
-		HandleFlock(tvc, uap->com, &treq, u.u_procp->p_pid,
-			    0 /*!onlymine */ );
-#else
-	    code = HandleFlock(tvc, uap->com, &treq, 0, 0 /*!onlymine */ );
-#endif
-#ifndef AFS_OSF_ENV
-	    u.u_error = code;
-#endif
-
-	    if (uap->com & LOCK_UN) {
-		/* gave up lock */
-		fd->f_flag &= ~(FEXLOCK | FSHLOCK);
-	    } else {
-#ifdef AFS_OSF_ENV
-		if (!code) {
-#else /* AFS_OSF_ENV */
-		if (!u.u_error) {
-#endif
-		    if (uap->com & LOCK_SH)
-			fd->f_flag |= FSHLOCK;
-		    else if (uap->com & LOCK_EX)
-			fd->f_flag |= FEXLOCK;
-		}
-	    }
-	    flockDone = 1;
-	    fd->f_ops = &afs_fileops;
-	}
-    }
-#ifdef	AFS_OSF_ENV
-    if (!flockDone)
-	code = flock(p, args, retval);
-#ifdef	AFS_OSF30_ENV
-    FP_UNREF_ALWAYS(fd);
-#else
-    FP_UNREF(fd);
-#endif
-    AFS_DISCON_UNLOCK();
-    afs_PutFakeStat(&fakestate);
-    return code;
-#else /* AFS_OSF_ENV */
-    if (!flockDone)
-#ifdef DYNEL
-	(*afs_longcall_procs.LC_flock) ();
-#else
-	flock();
-#endif
-    AFS_DISCON_UNLOCK();
-    afs_PutFakeStat(&fakestate);
-    return;
-#endif
-}
-#endif /* !defined(AFS_AIX_ENV) && !defined(AFS_HPUX_ENV) && !defined(AFS_SUN5_ENV) && !defined(UKERNEL)  && !defined(AFS_LINUX20_ENV) */
