@@ -526,7 +526,7 @@ afs_syscall_call(long parm, long parm2, long parm3,
 #endif
 		    && (parm != AFSOP_GETMTU) && (parm != AFSOP_GETMASK)) {
 	/* only root can run this code */
-#if defined(AFS_OSF_ENV) || defined(AFS_SUN5_ENV) || defined(KERNEL_HAVE_UERROR)
+#if defined(AFS_SUN5_ENV) || defined(KERNEL_HAVE_UERROR)
 #if defined(KERNEL_HAVE_UERROR)
 	setuerror(EACCES);
 #endif
@@ -1313,11 +1313,25 @@ afs_shutdown(void)
     shutdown_bufferpackage();
     shutdown_cache();
     shutdown_osi();
+    /*
+     * Close file only after daemons which can write to it are stopped.
+     * Need to close before the osinet shutdown to avoid failing check
+     * for dangling memory allocations.
+     */
+    if (afs_cacheInodep) {	/* memcache won't set this */
+	osi_UFSClose(afs_cacheInodep);	/* Since we always leave it open */
+	afs_cacheInodep = 0;
+    }
+    /*
+     * Shutdown the ICL logs - needed to free allocated memory space and avoid
+     * warnings from shutdown_osinet
+     */
+    shutdown_icl();
     shutdown_osinet();
     shutdown_osifile();
     shutdown_vnodeops();
     shutdown_memcache();
-#if (!defined(AFS_NONFSTRANS) || defined(AFS_AIX_IAUTH_ENV)) && !defined(AFS_OSF_ENV)
+#if (!defined(AFS_NONFSTRANS) || defined(AFS_AIX_IAUTH_ENV))
     shutdown_exporter();
     shutdown_nfsclnt();
 #endif
@@ -1330,12 +1344,6 @@ afs_shutdown(void)
 */
     afs_warn(" ALL allocated tables\n");
 
-    /* Close file only after daemons which can write to it are stopped. */
-    if (afs_cacheInodep) {	/* memcache won't set this */
-	osi_UFSClose(afs_cacheInodep);	/* Since we always leave it open */
-	afs_cacheInodep = 0;
-    }
-
     afs_shuttingdown = 0;
 
     return;			/* Just kill daemons for now */
