@@ -35,7 +35,7 @@ FillStoreStats(int code, int idx, osi_timeval_t *xferStartTime,
 {
     struct afs_stats_xferData *xferP;
     osi_timeval_t xferStopTime;
-    XSTATS_DECLS;
+    osi_timeval_t elapsedTime;
 
     xferP = &(afs_stats_cmfullperf.rpc.fsXferTimes[idx]);
     osi_GetuTime(&xferStopTime);
@@ -84,7 +84,7 @@ struct rxfs_storeVariables {
     struct rx_call *call;
     char *tbuffer;
     struct iovec *tiov;
-    afs_uint32 tnio;
+    afs_int32 tnio;
     afs_int32 hasNo64bit;
     struct AFSStoreStatus InStatus;
 };
@@ -213,7 +213,7 @@ rxfs_storePadd(void *rock, afs_uint32 size)
 	    return -33;	/* XXX */
 	size -= tlen;
     }
-    return code;
+    return 0;
 }
 
 afs_int32
@@ -454,7 +454,7 @@ afs_CacheStoreDCaches(struct vcache *avc, struct dcache **dclist,
 
 	while ( size > 0 ) {
 	    afs_uint32 tlen;
-	    afs_int32 bytesread, byteswritten;
+	    afs_uint32 bytesread, byteswritten;
 	    code = (*ops->prepare)(rock, size, &tlen);
 	    if ( code )
 		break;
@@ -593,28 +593,26 @@ afs_CacheStoreVCache(struct dcache **dcList, struct vcache *avc,
 		       ICL_HANDLE_OFFSET(base), ICL_TYPE_OFFSET,
 		       ICL_HANDLE_OFFSET(bytes), ICL_TYPE_OFFSET,
 		       ICL_HANDLE_OFFSET(length));
-	    tc = afs_Conn(&avc->f.fid, areq, 0);
 
 	    do {
+	        tc = afs_Conn(&avc->f.fid, areq, 0);
+
 #ifdef AFS_64BIT_CLIENT
 	      restart:
 #endif
 		code = rxfs_storeInit(avc, tc, base, bytes, length,
-					sync, &ops, &rock);
-		if ( code )
-		    goto nocall;
+				      sync, &ops, &rock);
+		if ( !code ) {
+		    code = afs_CacheStoreDCaches(avc, dclist, bytes, anewDV,
+			                         &doProcessFS, &OutStatus,
+						 nchunks, nomore, ops, rock);
+		}
 
-		code = afs_CacheStoreDCaches(avc, dclist, bytes, anewDV,
-			&doProcessFS, &OutStatus, nchunks, nomore, ops, rock);
-
-nocall:
 #ifdef AFS_64BIT_CLIENT
 		if (code == RXGEN_OPCODE && !afs_serverHasNo64Bit(tc)) {
 		    afs_serverSetNo64Bit(tc);
 		    goto restart;
 		}
-#else
-		continue;	/* dummy, label before block end won't work */
 #endif /* AFS_64BIT_CLIENT */
 	    } while (afs_Analyze
 		     (tc, code, &avc->f.fid, areq,
@@ -692,7 +690,7 @@ struct rxfs_fetchVariables {
     struct rx_call *call;
     char *tbuffer;
     struct iovec *iov;
-    afs_uint32 nio;
+    afs_int32 nio;
     afs_int32 hasNo64bit;
     afs_int32 iovno;
     afs_int32 iovmax;
@@ -819,7 +817,7 @@ rxfs_fetchDestroy(void **r, afs_int32 error)
 }
 
 afs_int32
-rxfs_fetchMore(void *r, afs_uint32 *length, afs_uint32 *moredata)
+rxfs_fetchMore(void *r, afs_int32 *length, afs_uint32 *moredata)
 {
     afs_int32 code;
     struct rxfs_fetchVariables *v = (struct rxfs_fetchVariables *)r;
@@ -833,14 +831,16 @@ rxfs_fetchMore(void *r, afs_uint32 *length, afs_uint32 *moredata)
      * We do not do this for AFS file servers because they sometimes
      * return large negative numbers as the transfer size.
      */
-    RX_AFS_GUNLOCK();
-    code = rx_Read(v->call, (void *)length, sizeof(afs_int32));
-    RX_AFS_GLOCK();
-    *length = ntohl(*length);
-    if (code != sizeof(afs_int32)) {
-	code = rx_Error(v->call);
-	*moredata = 0;
-	return (code ? code : -1);	/* try to return code, not -1 */
+    if (*moredata) {
+	RX_AFS_GUNLOCK();
+	code = rx_Read(v->call, (void *)length, sizeof(afs_int32));
+	RX_AFS_GLOCK();
+	*length = ntohl(*length);
+	if (code != sizeof(afs_int32)) {
+	    code = rx_Error(v->call);
+	    *moredata = 0;
+	    return (code ? code : -1);	/* try to return code, not -1 */
+        }
     }
     *moredata = *length & 0x80000000;
     *length &= ~0x80000000;
@@ -867,13 +867,15 @@ struct fetchOps rxfs_fetchMemOps = {
 
 afs_int32
 rxfs_fetchInit(struct afs_conn *tc, struct vcache *avc, afs_offs_t base,
-		afs_uint32 size, afs_uint32 *alength, afs_uint32 *moredata,
-		struct dcache *adc,
+		afs_uint32 size, afs_int32 *alength, struct dcache *adc,
 		struct osi_file *fP, struct fetchOps **ops, void **rock)
 {
     struct rxfs_fetchVariables *v;
-    int code = 0, code1;
-    afs_uint32 length_hi = 0, length, bytes;
+    int code = 0, code1 = 0;
+#ifdef AFS_64BIT_CLIENT
+    afs_uint32 length_hi = 0;
+#endif
+    afs_uint32 length, bytes;
 
     v = (struct rxfs_fetchVariables *) osi_AllocSmallSpace(sizeof(struct rxfs_fetchVariables));
     if (!v)
@@ -945,7 +947,7 @@ rxfs_fetchInit(struct afs_conn *tc, struct vcache *avc, afs_offs_t base,
 		   ICL_TYPE_POINTER, avc, ICL_TYPE_INT32, code,
 		   ICL_TYPE_OFFSET,
 		   ICL_HANDLE_OFFSET(length64));
-	*alength = length64;
+	*alength = length;
 #else /* AFS_64BIT_CLIENT */
 	RX_AFS_GUNLOCK();
 	code = StartRXAFS_FetchData(v->call, (struct AFSFid *)&avc->f.fid.Fid,
@@ -967,26 +969,14 @@ rxfs_fetchInit(struct afs_conn *tc, struct vcache *avc, afs_offs_t base,
 #endif /* AFS_64BIT_CLIENT */
     } else
 	code = -1;
+
+    if (!code && code1)
+	code = code1;
+
     if (code) {
 	osi_FreeSmallSpace(v);
         return code;
     }
-    /*
-     * The fetch protocol is extended for the AFS/DFS translator
-     * to allow multiple blocks of data, each with its own length,
-     * to be returned. As long as the top bit is set, there are more
-     * blocks expected.
-     *
-     * We do not do this for AFS file servers because they sometimes
-     * return large negative numbers as the transfer size.
-     *
-     * Also omit if length > 2^32, as bit 31 is part of the number then.
-     * Known to never be the case ifndef AFS_64BIT_CLIENT.
-     */
-    if (avc->f.states & CForeign && !length_hi) {
-	*moredata = length & 0x80000000;
-	length &= ~0x80000000;
-    }
     if (cacheDiskType == AFS_FCACHE_TYPE_UFS) {
 	v->tbuffer = osi_AllocLargeSpace(AFS_LRALLOCSIZ);
 	if (!v->tbuffer)
@@ -1033,11 +1023,11 @@ afs_CacheFetchProc(struct afs_conn *tc, struct osi_file *fP, afs_size_t base,
 		    struct afs_FetchOutput *tsmall)
 {
     afs_int32 code;
-    afs_uint32 length;
+    afs_int32 length;
     afs_uint32 bytesread, byteswritten;
     struct fetchOps *ops = NULL;
     void *rock = NULL;
-    int moredata = 0;
+    afs_uint32 moredata = 0;
     int offset = 0;
 
     XSTATS_DECLS;
@@ -1057,7 +1047,7 @@ afs_CacheFetchProc(struct afs_conn *tc, struct osi_file *fP, afs_size_t base,
      * adc->lock(W)
      */
     code = rxfs_fetchInit(
-		tc, avc, base, size, &length, &moredata, adc, fP, &ops, &rock);
+		tc, avc, base, size, &length, adc, fP, &ops, &rock);
 
 #ifndef AFS_NOSTATS
     osi_GetuTime(&xferStartTime);
@@ -1068,7 +1058,7 @@ afs_CacheFetchProc(struct afs_conn *tc, struct osi_file *fP, afs_size_t base,
     }
 
     if ( !code ) do {
-	if ((avc->f.states & CForeign) && moredata && !length) {
+	if (avc->f.states & CForeign) {
 	    code = (*ops->more)(rock, &length, &moredata);
 	    if ( code )
 		break;
@@ -1076,7 +1066,7 @@ afs_CacheFetchProc(struct afs_conn *tc, struct osi_file *fP, afs_size_t base,
 #ifndef AFS_NOSTATS
 	bytesToXfer += length;
 #endif /* AFS_NOSTATS */
-	while (length) {
+	while (length > 0) {
 #ifdef RX_KERNEL_TRACE
 	    afs_Trace1(afs_iclSetp, CM_TRACE_TIMESTAMP, ICL_TYPE_STRING,
 		       "before rx_Read");
