@@ -32,8 +32,6 @@
 #include <afsconfig.h>
 #include "afs/param.h"
 
-RCSID
-    ("$Header: /cvs/openafs/src/afs/afs_server.c,v 1.43.4.11 2009/03/18 13:41:35 shadow Exp $");
 
 #include "afs/stds.h"
 #include "afs/sysincludes.h"	/* Standard vendor system headers */
@@ -383,25 +381,25 @@ afs_CountServers(void)
     afs_stats_cmperf.fs_UpDown[0].sumOfRecordAges = 0;
     afs_stats_cmperf.fs_UpDown[0].ageOfYoungestRecord = 0;
     afs_stats_cmperf.fs_UpDown[0].ageOfOldestRecord = 0;
-    memset((char *)afs_stats_cmperf.fs_UpDown[0].downIncidents, 0,
+    memset(afs_stats_cmperf.fs_UpDown[0].downIncidents, 0,
 	   AFS_STATS_NUM_DOWNTIME_INCIDENTS_BUCKETS * sizeof(afs_int32));
 
     afs_stats_cmperf.fs_UpDown[1].sumOfRecordAges = 0;
     afs_stats_cmperf.fs_UpDown[1].ageOfYoungestRecord = 0;
     afs_stats_cmperf.fs_UpDown[1].ageOfOldestRecord = 0;
-    memset((char *)afs_stats_cmperf.fs_UpDown[1].downIncidents, 0,
+    memset(afs_stats_cmperf.fs_UpDown[1].downIncidents, 0,
 	   AFS_STATS_NUM_DOWNTIME_INCIDENTS_BUCKETS * sizeof(afs_int32));
 
     afs_stats_cmperf.vl_UpDown[0].sumOfRecordAges = 0;
     afs_stats_cmperf.vl_UpDown[0].ageOfYoungestRecord = 0;
     afs_stats_cmperf.vl_UpDown[0].ageOfOldestRecord = 0;
-    memset((char *)afs_stats_cmperf.vl_UpDown[0].downIncidents, 0,
+    memset(afs_stats_cmperf.vl_UpDown[0].downIncidents, 0,
 	   AFS_STATS_NUM_DOWNTIME_INCIDENTS_BUCKETS * sizeof(afs_int32));
 
     afs_stats_cmperf.vl_UpDown[1].sumOfRecordAges = 0;
     afs_stats_cmperf.vl_UpDown[1].ageOfYoungestRecord = 0;
     afs_stats_cmperf.vl_UpDown[1].ageOfOldestRecord = 0;
-    memset((char *)afs_stats_cmperf.vl_UpDown[1].downIncidents, 0,
+    memset(afs_stats_cmperf.vl_UpDown[1].downIncidents, 0,
 	   AFS_STATS_NUM_DOWNTIME_INCIDENTS_BUCKETS * sizeof(afs_int32));
 
     /*
@@ -489,7 +487,7 @@ afs_CountServers(void)
 
 
 void
-ForceAllNewConnections()
+ForceAllNewConnections(void)
 {
     int srvAddrCount;
     struct srvAddr **addrs;
@@ -1525,8 +1523,10 @@ static int afs_SetServerPrefs(struct srvAddr *sa) {
 	    afsi_SetServerIPRank(sa, ifa);
     }}
 #endif
-    end:
 #endif				/* USEIFADDR */
+#ifndef USEIFADDR
+    end:
+#endif
 #endif				/* AFS_SUN5_ENV */
 #endif				/* else AFS_USERSPACE_IP_ADDR */
     if (sa)
@@ -1560,7 +1560,7 @@ void afs_FlushServer(struct server *srvp) {
     if (srvp->cbrs) {
 	struct afs_cbr *cb, *cbnext;
 
-	  MObtainWriteLock(&afs_xvcb, 300);
+	  ObtainWriteLock(&afs_xvcb, 300);
 	for (cb = srvp->cbrs; cb; cb = cbnext) {
 	    cbnext = cb->next;
 	    afs_FreeCBR(cb);
@@ -1686,7 +1686,7 @@ struct server *afs_GetServer(afs_uint32 * aserverp, afs_int32 nservers,
 	if (!newts)
 	    panic("malloc of server struct");
 	afs_totalServers++;
-	memset((char *)newts, 0, sizeof(struct server));
+	memset(newts, 0, sizeof(struct server));
 
 	/* Add the server struct to the afs_servers[] hash chain */
 	srvhash =
@@ -1731,7 +1731,7 @@ struct server *afs_GetServer(afs_uint32 * aserverp, afs_int32 nservers,
 	    if (!newsa)
 		panic("malloc of srvAddr struct");
 	    afs_totalSrvAddrs++;
-	    memset((char *)newsa, 0, sizeof(struct srvAddr));
+	    memset(newsa, 0, sizeof(struct srvAddr));
 
 	    /* Add the new srvAddr to the afs_srvAddrs[] hash chain */
 	    newsa->next_bkt = afs_srvAddrs[iphash];
@@ -1781,7 +1781,7 @@ struct server *afs_GetServer(afs_uint32 * aserverp, afs_int32 nservers,
 		    (struct server *)afs_osi_Alloc(sizeof(struct server));
 		if (!orphts)
 		    panic("malloc of lo server struct");
-		memset((char *)orphts, 0, sizeof(struct server));
+		memset(orphts, 0, sizeof(struct server));
 		afs_totalServers++;
 
 		/* Add the orphaned server to the afs_servers[] hash chain.
@@ -1852,7 +1852,7 @@ void afs_ActivateServer(struct srvAddr *sap) {
     }
 }
 
-void afs_RemoveAllConns()
+void afs_RemoveAllConns(void)
 {
     int i;
     struct server *ts, *nts;
@@ -1889,7 +1889,7 @@ void afs_RemoveAllConns()
     
 }
 
-void afs_MarkAllServersUp()
+void afs_MarkAllServersUp(void)
 {
     int i;
     struct server *ts;
@@ -1908,7 +1908,7 @@ void afs_MarkAllServersUp()
     ReleaseWriteLock(&afs_xserver);
 }
 
-void shutdown_server()
+void shutdown_server(void)
 {
     int i;
 
