@@ -10,8 +10,6 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID
-    ("$Header: /cvs/openafs/src/bozo/bos.c,v 1.23.2.5 2009/03/17 04:45:07 shadow Exp $");
 
 #include <afs/stds.h>
 #include <stdlib.h>
@@ -55,6 +53,7 @@ static int DoStat(char *aname, register struct rx_connection *aconn,
 		  int aint32p, int firstTime);
 
 #include "bosint.h"
+#include "bosprototypes.h"
 
 /* command offsets for bos salvage command */
 #define MRAFS_OFFSET  10
@@ -191,40 +190,42 @@ GetConn(struct cmd_syndesc *as, int aencrypt)
     }
     memcpy(&addr, th->h_addr, sizeof(afs_int32));
 
-    /* get tokens for making authenticated connections */
-    localauth = (as->parms[ADDPARMOFFSET + 2].items != 0);
-    confdir =
-	(localauth ? AFSDIR_SERVER_ETC_DIRPATH : AFSDIR_CLIENT_ETC_DIRPATH);
-    tdir = afsconf_Open(confdir);
-    if (tdir) {
-	struct afsconf_cell info;
-	char *tname;
-
-	if (as->parms[ADDPARMOFFSET].items)
-	    tname = as->parms[ADDPARMOFFSET].items->data;
-	else
-	    tname = NULL;
-	/* next call expands cell name abbrevs for us and handles looking up
-	 * local cell */
-	code = afsconf_GetCellInfo(tdir, tname, NULL, &info);
-	if (code) {
-	    afs_com_err("bos", code, "(can't find cell '%s' in cell database)",
-		    (tname ? tname : "<default>"));
-	    exit(1);
-	} else
-	    strcpy(sname.cell, info.name);
-    } else {
-	printf("bos: can't open cell database (%s)\n", confdir);
-	exit(1);
-    }
-    sname.instance[0] = 0;
-    strcpy(sname.name, "afs");
+    /* Start with no authentication */
     sc[0] = rxnull_NewClientSecurityObject();
     sc[1] = 0;
     sc[2] = 0;
     scIndex = 0;
 
     if (!as->parms[ADDPARMOFFSET + 1].items) {	/* not -noauth */
+        /* get tokens for making authenticated connections */
+        localauth = (as->parms[ADDPARMOFFSET + 2].items != 0);
+        confdir =
+            (localauth ? AFSDIR_SERVER_ETC_DIRPATH : AFSDIR_CLIENT_ETC_DIRPATH);
+        tdir = afsconf_Open(confdir);
+        if (tdir) {
+            struct afsconf_cell info;
+            char *tname;
+
+            if (as->parms[ADDPARMOFFSET].items)
+                tname = as->parms[ADDPARMOFFSET].items->data;
+            else
+                tname = NULL;
+            /* next call expands cell name abbrevs for us and handles looking up
+            * local cell */
+            code = afsconf_GetCellInfo(tdir, tname, NULL, &info);
+            if (code) {
+                afs_com_err("bos", code, "(can't find cell '%s' in cell database)",
+                             (tname ? tname : "<default>"));
+                exit(1);
+            } else
+                strcpy(sname.cell, info.name);
+        } else {
+            printf("bos: can't open cell database (%s)\n", confdir);
+            exit(1);
+        }
+        sname.instance[0] = 0;
+        strcpy(sname.name, "afs");
+
 	if (as->parms[ADDPARMOFFSET + 2].items) {	/* -localauth */
 	    code = afsconf_GetLatestKey(tdir, 0, 0);
 	    if (code)
@@ -906,7 +907,7 @@ AddKey(register struct cmd_syndesc *as, void *arock)
 	ka_StringToKey(buf, tcell, &tkey);
     }
     tconn = GetConn(as, 1);
-    code = BOZO_AddKey(tconn, temp, &tkey);
+    code = BOZO_AddKey(tconn, temp, ktc_to_bozoptr(&tkey));
     if (code) {
 	printf("bos: failed to set key %d (%s)\n", temp, em(code));
 	exit(1);
@@ -948,14 +949,14 @@ ListKeys(register struct cmd_syndesc *as, void *arock)
     tconn = GetConn(as, 1);
     everWorked = 0;
     for (i = 0;; i++) {
-	code = BOZO_ListKeys(tconn, i, &kvno, &tkey, &keyInfo);
+	code = BOZO_ListKeys(tconn, i, &kvno, ktc_to_bozoptr(&tkey), &keyInfo);
 	if (code)
 	    break;
 	everWorked = 1;
 	/* first check if key is returned */
-	if ((!ka_KeyIsZero(&tkey, sizeof(tkey))) && (as->parms[1].items)) {
+	if ((!ka_KeyIsZero(ktc_to_charptr(&tkey), sizeof(tkey))) && (as->parms[1].items)) {
 	    printf("key %d is '", kvno);
-	    ka_PrintBytes(&tkey, sizeof(tkey));
+	    ka_PrintBytes(ktc_to_charptr(&tkey), sizeof(tkey));
 	    printf("'\n");
 	} else {
 	    if (keyInfo.keyCheckSum == 0)	/* shouldn't happen */
@@ -1286,7 +1287,7 @@ DoSalvage(struct rx_connection * aconn, char * aparm1, char * aparm2,
 	    printf("bos: command line too big\n");
 	    return (E2BIG);
 	}
-	strcat(tbuffer, " -f ");
+	strcat(tbuffer, " -force ");
 	strcat(tbuffer, partName);
     }
 
@@ -1357,14 +1358,14 @@ DoSalvage(struct rx_connection * aconn, char * aparm1, char * aparm2,
 	if (mrafsParm->OptDontAskFS)
 	    strcat(tbuffer, " -DontAskFS");
 	if (mrafsParm->OptLogLevel) {
-	    sprintf(pbuffer, " -LogLevel %ld", afs_cast_int32(mrafsParm->OptLogLevel));
+	    sprintf(pbuffer, " -LogLevel %ld", afs_printable_int32_ld(mrafsParm->OptLogLevel));
 	    strcat(tbuffer, pbuffer);
 	}
 	if (mrafsParm->OptRxDebug)
 	    strcat(tbuffer, " -rxdebug");
 	if (mrafsParm->OptResidencies) {
 	    sprintf(pbuffer, " -Residencies %lu", 
-		    afs_cast_uint32(mrafsParm->OptResidencies));
+		    afs_printable_uint32_lu(mrafsParm->OptResidencies));
 	    strcat(tbuffer, pbuffer);
 	}
     }
