@@ -382,7 +382,7 @@ SBOZO_SetCellName(struct rx_call *acall, char *aname)
 
     code =
 	afsconf_GetExtendedCellInfo(bozo_confdir, NULL, NULL, &tcell,
-				    &clones);
+				    clones);
     if (code)
 	goto fail;
 
@@ -398,7 +398,7 @@ SBOZO_SetCellName(struct rx_call *acall, char *aname)
     strcpy(tcell.name, aname);
     code =
 	afsconf_SetExtendedCellInfo(bozo_confdir, AFSDIR_SERVER_ETC_DIRPATH,
-				    &tcell, &clones);
+				    &tcell, clones);
 
   fail:
     osi_auditU(acall, BOS_SetCellEvent, code, AUD_STR, aname, AUD_END);
@@ -434,7 +434,7 @@ SBOZO_GetCellHost(struct rx_call *acall, afs_uint32 awhich, char **aname)
 
     code =
 	afsconf_GetExtendedCellInfo(bozo_confdir, NULL, NULL, &tcell,
-				    &clones);
+				    clones);
     if (code)
 	goto fail;
 
@@ -480,7 +480,7 @@ SBOZO_DeleteCellHost(struct rx_call *acall, char *aname)
 
     code =
 	afsconf_GetExtendedCellInfo(bozo_confdir, NULL, NULL, &tcell,
-				    &clones);
+				    clones);
     if (code)
 	goto fail;
 
@@ -501,7 +501,7 @@ SBOZO_DeleteCellHost(struct rx_call *acall, char *aname)
     memset(tcell.hostName[which], 0, MAXHOSTCHARS);
     code =
 	afsconf_SetExtendedCellInfo(bozo_confdir, AFSDIR_SERVER_ETC_DIRPATH,
-				    &tcell, &clones);
+				    &tcell, clones);
 
   fail:
     osi_auditU(acall, BOS_DeleteHostEvent, code, AUD_STR, aname, AUD_END);
@@ -529,7 +529,7 @@ SBOZO_AddCellHost(struct rx_call *acall, char *aname)
 
     code =
 	afsconf_GetExtendedCellInfo(bozo_confdir, NULL, NULL, &tcell,
-				    &clones);
+				    clones);
     if (code)
 	goto fail;
 
@@ -582,7 +582,7 @@ SBOZO_AddCellHost(struct rx_call *acall, char *aname)
     clones[which] = isClone;
     code =
 	afsconf_SetExtendedCellInfo(bozo_confdir, AFSDIR_SERVER_ETC_DIRPATH,
-				    &tcell, &clones);
+				    &tcell, clones);
 
   fail:
     osi_auditU(acall, BOS_AddHostEvent, code, AUD_STR, aname, AUD_END);
@@ -664,7 +664,7 @@ SBOZO_AddKey(struct rx_call *acall, afs_int32 an, struct bozo_key *akey)
     if (DoLogging)
 	bozo_Log("%s is executing AddKey\n", caller);
 
-    code = afsconf_AddKey(bozo_confdir, an, akey, 0);
+    code = afsconf_AddKey(bozo_confdir, an, akey->data, 0);
     if (code == AFSCONF_KEYINUSE)
 	code = BZKEYINUSE;	/* Unique code for afs rpc calls */
   fail:
