@@ -10,6 +10,9 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
+#ifdef IGNORE_SOME_GCC_WARNINGS
+# pragma GCC diagnostic warning "-Wdeprecated-declarations"
+#endif
 
 #include <afs/stds.h>
 #include <sys/types.h>
@@ -293,7 +296,6 @@ ReadBozoFile(char *aname)
 	    if (code < 0)
 		perror("bosconfig rename");
 	}
-#ifdef BOS_NEW_CONFIG
 	if (access(AFSDIR_SERVER_BOZCONFNEW_FILEPATH, 0) == 0) {
 	    code =
 		renamefile(AFSDIR_SERVER_BOZCONFNEW_FILEPATH,
@@ -301,7 +303,6 @@ ReadBozoFile(char *aname)
 	    if (code < 0)
 		perror("bosconfig rename");
 	}
-#endif
     }
 
     /* setup default times we want to do restarts */
@@ -834,7 +835,7 @@ main(int argc, char **argv, char **envp)
 	    rxMaxMTU = atoi(argv[++code]);
 	    if ((rxMaxMTU < RX_MIN_PACKET_SIZE) || 
 		(rxMaxMTU > RX_MAX_PACKET_DATA_SIZE)) {
-		printf("rxMaxMTU %d invalid; must be between %d-%lu\n",
+		printf("rxMaxMTU %d invalid; must be between %d-%" AFS_SIZET_FMT "\n",
 			rxMaxMTU, RX_MIN_PACKET_SIZE, 
 			RX_MAX_PACKET_DATA_SIZE);
 		exit(1);
