@@ -1,3 +1,16 @@
+/*
+ * Copyright 2000, International Business Machines Corporation and others.
+ * All Rights Reserved.
+ *
+ * This software has been released under the terms of the IBM Public
+ * License.  For details, see the LICENSE file in the top-level source
+ * directory or online at http://www.openafs.org/dl/license10.html
+ */
+#ifndef AFS_SRC_KAUTH_INTERNAL_H
+#define AFS_SRC_KAUTH_INTERNAL_H
+
+/* admin_tools.c */
+extern afs_int32 ka_AdminInteractive(int cmd_argc, char *cmd_argv[]);
 
 /* kadatabase.c */
 extern void init_kadatabase(int initFlags);
@@ -7,6 +20,7 @@ extern afs_int32 ka_LookupKey(struct ubik_trans *tt,
 			      afs_int32 *kvno,
 			      struct ktc_encryptionKey *key);
 
+struct kaentry;
 extern afs_int32 FindBlock(struct ubik_trans *at, char *aname, 
 			   char *ainstance, afs_int32 *toP, 
 			   struct kaentry *tentry);
@@ -27,6 +41,19 @@ extern afs_int32 ka_NewKey(struct ubik_trans *tt, afs_int32 tentryaddr,
 
 extern int name_instance_legal(char *name, char *instance);
 
+/* kalog.c */
+extern void kalog_Init(void);
+
+/* kaprocs.c */
+struct ubik_trans;
+extern afs_int32 InitAuthServ(struct ubik_trans **, int, int *);
+
+/* krb_tf.c */
+extern afs_int32 krb_write_ticket_file(char *realm);
+
+/* krb_udp.c */
+extern afs_int32 init_krb_udp(void);
+
 static_inline unsigned char *
 EncryptionKey_to_cblock(EncryptionKey *key) {
     return (unsigned char *)key;
@@ -41,3 +68,5 @@ static_inline EncryptionKey *
 ktc_to_EncryptionKey(struct ktc_encryptionKey *key) {
     return (EncryptionKey *)key;
 }
+
+#endif
