@@ -10,8 +10,6 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID
-    ("$Header: /cvs/openafs/src/kauth/user_nt.c,v 1.13 2004/08/19 01:07:47 kolya Exp $");
 
 #include <afs/stds.h>
 
@@ -22,6 +20,7 @@ RCSID
 #include <stdio.h>		/* sprintf */
 #include <malloc.h>
 #include <afs/kautils.h>
+#include <afs/cm.h>
 #include <afs/cm_config.h>
 #include <afs/krb.h>
 #include <afs/krb_prot.h>
@@ -107,7 +106,9 @@ ka_UserAuthenticateGeneral2(afs_int32 flags, char *name, char *instance,
     if (lifetime == 0)
 	lifetime = MAXKTCTICKETLIFETIME;
 
-    code = cm_SearchCellFile(realm, fullRealm, ka_AddHostProc, NULL);
+    code = cm_SearchCellRegistry(1, realm, fullRealm, NULL, ka_AddHostProc, NULL);
+    if (code && code != CM_ERROR_FORCE_DNS_LOOKUP)
+        code = cm_SearchCellFile(realm, fullRealm, ka_AddHostProc, NULL);
 
 #ifdef AFS_AFSDB_ENV
     if (code) {
@@ -715,7 +716,7 @@ send_to_kdc(pkt, rpkt)
     struct sockaddr_in to;
     int timeAvail, timePerIter, numIters;
 
-    memset((char *)&to, 0, sizeof(to));
+    memset(&to, 0, sizeof(to));
     if ((f = socket(AF_INET, SOCK_DGRAM, 0)) < 0) {
 	if (krb_debug)
 	    fprintf(stderr, "%s: Can't open socket\n", prog);
