@@ -211,8 +211,8 @@ readUbikHeader(struct misc_data *misc)
     /* now read the info */
     r = read(fd, &uheader, sizeof(uheader));
     if (r != sizeof(uheader)) {
-	printf("error: read of %lu bytes failed: %d %d\n", sizeof(uheader), r,
-	       errno);
+	printf("error: read of %" AFS_SIZET_FMT " bytes failed: %d %d\n",
+	       sizeof(uheader), r, errno);
 	return (-1);
     }
 
@@ -1510,7 +1510,7 @@ void
 zeromap(struct idused *idmap)
 {
     while (idmap) {
-	memset((char *)idmap->idcount, 0, sizeof idmap->idcount);
+	memset(idmap->idcount, 0, sizeof idmap->idcount);
 	idmap = idmap->idnext;
     }
 }
@@ -1535,7 +1535,7 @@ inccount(struct idused **idmapp, int id)
 	    perror("idmap");
 	    exit(1);
 	}
-	memset((char *)idmap, 0, sizeof idmap);
+	memset(idmap, 0, sizeof idmap);
 	idmap->idstart = id & ~(IDCOUNT - 1);
 	idmap->idnext = *idmapp;
 	*idmapp = idmap;
