@@ -31,8 +31,6 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID
-    ("$Header: /cvs/openafs/src/ptserver/map.c,v 1.3.14.4 2009/03/16 13:08:56 shadow Exp $");
 
 #ifdef SUPERGROUPS
 #include <errno.h>
@@ -162,7 +160,7 @@ add_map(struct map *parm, int node)
 	    return 0;
 	}
 	map->m_page = page;
-	memset((char *) map->m_data, 0, sizeof map->m_data);
+	memset( map->m_data, 0, sizeof map->m_data);
 	if (NEGMAP(parm)) {
 	    int i;
 	    for (i = 0; i < MDATA; ++i)
@@ -717,7 +715,7 @@ read_map(int (*f) (void *), char *arg)
 		    free_map((struct map *)result);
 		return 0;
 	    }
-	    memset((char *) map->m_data, 0, sizeof map->m_data);
+	    memset( map->m_data, 0, sizeof map->m_data);
 	    map->m_page = page;
 	    map->m_next = 0;
 	    *mp = map;
