@@ -111,8 +111,6 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID
-    ("$Header: /cvs/openafs/src/ptserver/ptserver.c,v 1.25.2.16 2009/03/23 19:41:00 shadow Exp $");
 
 #include <afs/stds.h>
 #ifdef	AFS_AIX32_ENV
@@ -212,7 +210,6 @@ main(int argc, char **argv)
     char hostname[64];
     struct rx_service *tservice;
     struct rx_securityClass *sc[3];
-    extern int RXSTATS_ExecuteRequest();
 #if 0
     struct ktc_encryptionKey tkey;
 #endif
@@ -227,6 +224,8 @@ main(int argc, char **argv)
     int a;
     char arg[100];
 
+    char *auditFileName = NULL;
+
 #ifdef	AFS_AIX32_ENV
     /*
      * The following signal action for AIX is necessary so that in case of a 
@@ -274,16 +273,16 @@ main(int argc, char **argv)
 	int alen;
 	lcstring(arg, argv[a], sizeof(arg));
 	alen = strlen(arg);
-	if ((strncmp(arg, "-database", alen) == 0)
-	    || (strncmp(arg, "-db", alen) == 0)) {
-	    pr_dbaseName = argv[++a];	/* specify a database */
-	} else if (strcmp(argv[a], "-d") == 0) {
+	if (strcmp(argv[a], "-d") == 0) {
 	    if ((a + 1) >= argc) {
 		fprintf(stderr, "missing argument for -d\n"); 
 		return -1; 
 	    }
 	    debuglevel = atoi(argv[++a]);
 	    LogLevel = debuglevel;
+	} else if ((strncmp(arg, "-database", alen) == 0)
+	    || (strncmp(arg, "-db", alen) == 0)) {
+	    pr_dbaseName = argv[++a];	/* specify a database */
 	} else if (strncmp(arg, "-p", alen) == 0) {
 	    lwps = atoi(argv[++a]);
 	    if (lwps > 16) {	/* maximum of 16 */
@@ -331,10 +330,14 @@ main(int argc, char **argv)
 	}
 #endif
 	else if (strncmp(arg, "-auditlog", alen) == 0) {
-	    char *fileName = argv[++a];
+	    auditFileName = argv[++a];
 
-            osi_audit_file(fileName);
-            osi_audit(PTS_StartEvent, 0, AUD_END);
+	} else if (strncmp(arg, "-audit-interface", alen) == 0) {
+	    char *interface = argv[++a];
+	    if (osi_audit_interface(interface)) {
+		printf("Invalid audit interface '%s'\n", interface);
+		PT_EXIT(1);
+	    }
 	}
 	else if (!strncmp(arg, "-rxmaxmtu", alen)) {
 	    if ((a + 1) >= argc) {
@@ -344,7 +347,7 @@ main(int argc, char **argv)
 	    rxMaxMTU = atoi(argv[++a]);
 	    if ((rxMaxMTU < RX_MIN_PACKET_SIZE) ||
 		 (rxMaxMTU > RX_MAX_PACKET_DATA_SIZE)) {
-		printf("rxMaxMTU %lu invalid; must be between %d-%d\n",
+		printf("rxMaxMTU %d invalid; must be between %d-%" AFS_SIZET_FMT "\n",
 			rxMaxMTU, RX_MIN_PACKET_SIZE,
 			RX_MAX_PACKET_DATA_SIZE);
 		PT_EXIT(1);
@@ -357,6 +360,7 @@ main(int argc, char **argv)
 #ifndef AFS_NT40_ENV
 	    printf("Usage: ptserver [-database <db path>] "
 		   "[-auditlog <log path>] "
+		   "[-audit-interface <file|sysvmq> (default is file)] "
 		   "[-syslog[=FACILITY]] [-d <debug level>] "
 		   "[-p <number of processes>] [-rebuild] "
 		   "[-groupdepth <depth>] "
@@ -367,7 +371,9 @@ main(int argc, char **argv)
 		   "[-help]\n");
 #else /* AFS_NT40_ENV */
 	    printf("Usage: ptserver [-database <db path>] "
-		   "[-auditlog <log path>] [-d <debug level>] "
+		   "[-auditlog <log path>] "
+		   "[-audit-interface <file|sysvmq> (default is file)] "
+		   "[-d <debug level>] "
 		   "[-p <number of processes>] [-rebuild] [-rxbind] "
 		   "[-allow-dotted-principals] "
 		   "[-default_access default_user_access default_group_access] "
@@ -377,7 +383,9 @@ main(int argc, char **argv)
 #else
 #ifndef AFS_NT40_ENV
 	    printf("Usage: ptserver [-database <db path>] "
-		   "[-auditlog <log path>] [-d <debug level>] "
+		   "[-auditlog <log path>] "
+		   "[-audit-interface <file|sysvmq> (default is file)] "
+		   "[-d <debug level>] "
 		   "[-syslog[=FACILITY]] "
 		   "[-p <number of processes>] [-rebuild] "
 		   "[-enable_peer_stats] [-enable_process_stats] "
@@ -405,6 +413,11 @@ main(int argc, char **argv)
 #endif
     }
 
+    if (auditFileName) {
+	osi_audit_file(auditFileName);
+	osi_audit(PTS_StartEvent, 0, AUD_END);
+    }
+
 #ifndef AFS_NT40_ENV
     serverLogSyslogTag = "ptserver";
 #endif
@@ -439,7 +452,7 @@ main(int argc, char **argv)
 
     /* get list of servers */
     code =
-	afsconf_GetExtendedCellInfo(prdir, NULL, "afsprot", &info, &clones);
+	afsconf_GetExtendedCellInfo(prdir, NULL, "afsprot", &info, clones);
     if (code) {
 	afs_com_err(whoami, code, "Couldn't get server list");
 	PT_EXIT(2);
