@@ -9,10 +9,9 @@
 
 #include <afsconfig.h>
 #include <afs/param.h>
-RCSID
-    ("$Header: /cvs/openafs/src/util/volparse.c,v 1.11.14.4 2009/01/22 15:16:37 jaltman Exp $");
 
 #include <string.h>
+#include <errno.h>
 #ifdef HAVE_STDLIB_H
 #include <stdlib.h>
 #endif
@@ -234,7 +233,7 @@ util_GetInt32(register char *as, afs_int32 * aval)
     negative = 0;
 
     /* skip over leading spaces */
-    for (; tc = *as; as++) {
+    for (tc = *as; tc !='\0'; as++, tc = *as) {
 	if (tc != ' ' && tc != '\t')
 	    break;
     }
@@ -257,7 +256,7 @@ util_GetInt32(register char *as, afs_int32 * aval)
 	base = 10;
 
     /* compute the # itself */
-    for (; tc = *as; as++) {
+    for (tc = *as; tc !='\0'; as++, tc = *as) {
 	if (!ismeta(tc, base))
 	    return -1;
 	total *= base;
@@ -281,7 +280,7 @@ util_GetUInt32(register char *as, afs_uint32 * aval)
     total = 0;			/* initialize things */
 
     /* skip over leading spaces */
-    for (; tc = *as; as++) {
+    for (tc = *as; tc !='\0'; as++, tc = *as) {
 	if (tc != ' ' && tc != '\t')
 	    break;
     }
@@ -298,7 +297,7 @@ util_GetUInt32(register char *as, afs_uint32 * aval)
 	base = 10;
 
     /* compute the # itself */
-    for (;tc = *as; as++) {
+    for (tc = *as; tc !='\0'; as++, tc = *as) {
 	if (!ismeta(tc, base))
 	    return -1;
 	total *= base;
@@ -308,3 +307,126 @@ util_GetUInt32(register char *as, afs_uint32 * aval)
     *aval = total;
     return 0;
 }
+
+static const char power_letter[] = {
+    'K',  /* kibi */
+    'M',  /* mebi */
+    'G',  /* gibi */
+    'T',  /* tebi */
+};
+
+afs_int32
+util_GetHumanInt32(register char *as, afs_int32 * aval)
+{
+    long value;
+    char * unit;
+    long mult = 1;
+    int exponent = 0;
+
+    errno = 0;
+    value = strtol(as, &unit, 0);
+    if (errno)
+	return -1;
+    if (unit[0] != 0) {
+	for (exponent = 0; exponent < sizeof(power_letter) && power_letter[exponent] != unit[0]; exponent++) {
+	    mult *= 1024;
+	}
+	if (exponent == sizeof(power_letter))
+	    return -1;
+    }
+    if (value > MAX_AFS_INT32 / mult || value < MIN_AFS_INT32 / mult)
+	return -1;
+
+    *aval = value * mult;
+
+    return 0;
+}
+
+afs_int32
+util_GetInt64(char *as, afs_int64 * aval)
+{
+    afs_int64 total;
+    int tc;
+    int base;
+    int negative;
+
+    total = 0; /* initialize things */
+    negative = 0;
+
+    /* skip over leading spaces */
+    while ((tc = *as)) {
+	if (tc != ' ' && tc != '\t')
+	    break;
+    }
+
+    /* compute sign */
+    if (*as == '-') {
+	negative = 1;
+	as++; /* skip over character */
+    }
+
+    /* compute the base */
+    if (*as == '0') {
+	as++;
+	if (*as == 'x' || *as == 'X') {
+	    base = 16;
+	    as++;
+	} else
+	    base = 8;
+    } else
+	base = 10;
+
+    /* compute the # itself */
+    while ((tc = *as)) {
+	if (!ismeta(tc, base))
+	    return -1;
+	total *= base;
+	total += getmeta(tc);
+	as++;
+    }
+
+    if (negative)
+	*aval = -total;
+    else
+	*aval = total;
+    return 0;
+}
+
+afs_uint32
+util_GetUInt64(char *as, afs_uint64 * aval)
+{
+    afs_uint64 total;
+    int tc;
+    int base;
+
+    total = 0; /* initialize things */
+
+    /* skip over leading spaces */
+    while ((tc = *as)) {
+	if (tc != ' ' && tc != '\t')
+	    break;
+    }
+
+    /* compute the base */
+    if (*as == '0') {
+	as++;
+	if (*as == 'x' || *as == 'X') {
+	    base = 16;
+	    as++;
+	} else
+	    base = 8;
+    } else
+	base = 10;
+
+    /* compute the # itself */
+    while ((tc = *as)) {
+	if (!ismeta(tc, base))
+	    return -1;
+	total *= base;
+	total += getmeta(tc);
+	as++;
+    }
+
+    *aval = total;
+    return 0;
+}
