@@ -36,8 +36,8 @@
 #include <sys/time.h>
 #endif /* ITIMER_REAL */
 #endif
-#if	defined(AFS_AIX_ENV) || defined(AFS_SUN4_ENV)
-#define WCOREDUMP(x)	(x & 0200)
+#ifndef WCOREDUMP
+#define WCOREDUMP(x)	((x) & 0200)
 #endif
 #include <rx/xdr.h>
 #include <afs/afsint.h>
@@ -274,6 +274,11 @@ handleit(struct cmd_syndesc *as, void *arock)
 	    vid = atoi(ti->data);
 	}
 
+	if (ShowLog) {
+	    printf("-showlog does not work with -client\n");
+	    exit(-1);
+	}
+
 	if (!seenpart || !seenvol) {
 	    printf("You must specify '-partition' and '-volumeid' with the '-client' option\n");
 	    exit(-1);
