@@ -56,14 +56,13 @@
 #include <fcntl.h>
 #include <sys/stat.h>
 
-#include "volser.h"
 #include <errno.h>
 #include <afs/audit.h>
 #include <afs/afsutil.h>
 #include <lwp.h>
 #include "volser.h"
 #include "volint.h"
-#include "volser_prototypes.h"
+#include "volser_internal.h"
 
 /*@printflike@*/ extern void Log(const char *format, ...);
 /*@printflike@*/ extern void Abort(const char *format, ...);
@@ -184,13 +183,17 @@ BKGSleep(void *unused)
 #endif
 	    VTRANS_LOCK;
 	    for (tt = TransList(); tt; tt = tt->next) {
+                VTRANS_OBJ_LOCK(tt);
 		if ((strcmp(tt->lastProcName, "DeleteVolume") == 0)
 		    || (strcmp(tt->lastProcName, "Clone") == 0)
 		    || (strcmp(tt->lastProcName, "ReClone") == 0)
 		    || (strcmp(tt->lastProcName, "Forward") == 0)
 		    || (strcmp(tt->lastProcName, "Restore") == 0)
-		    || (strcmp(tt->lastProcName, "ForwardMulti") == 0))
+		    || (strcmp(tt->lastProcName, "ForwardMulti") == 0)) {
+                    VTRANS_OBJ_UNLOCK(tt);
 		    break;
+                }
+                VTRANS_OBJ_UNLOCK(tt);
 	    }
 	    if (tt) {
 	        VTRANS_UNLOCK;
@@ -332,7 +335,7 @@ main(int argc, char **argv)
 	    rxMaxMTU = atoi(argv[++code]);
 	    if ((rxMaxMTU < RX_MIN_PACKET_SIZE) || 
 		(rxMaxMTU > RX_MAX_PACKET_DATA_SIZE)) {
-		printf("rxMaxMTU %d invalid; must be between %d-%lu\n",
+		printf("rxMaxMTU %d invalid; must be between %d-%" AFS_SIZET_FMT "\n",
 		       rxMaxMTU, RX_MIN_PACKET_SIZE, 
 		       RX_MAX_PACKET_DATA_SIZE);
 		exit(1);
